aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--oni-core.el9
1 files changed, 5 insertions, 4 deletions
diff --git a/oni-core.el b/oni-core.el
index 12bc3a1..de1a2a1 100644
--- a/oni-core.el
+++ b/oni-core.el
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.0823.214515
;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview dashboard)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -192,12 +192,13 @@ _s_: String list"
(setq-default truncate-lines t)
(setq-default fill-column 80)
+(add-hook 'Info-mode-hook 'mixed-pitch-mode)
+(add-hook 'after-save-hook 'executable-make-buffer-file-executable-if-script-p)
+(add-hook 'auto-save-hook #'oni-core--ensure-autosave-directory-exists)
(add-hook 'before-save-hook 'time-stamp)
(add-hook 'electric-indent-local-mode-hook #'oni-core--switch-newline-keys)
(add-hook 'minibuffer-setup-hook 'electric-pair-local-mode)
(add-hook 'prog-mode-hook 'goto-address-prog-mode)
-(add-hook 'auto-save-hook #'oni-core--ensure-autosave-directory-exists)
-(add-hook 'after-save-hook 'executable-make-buffer-file-executable-if-script-p)
(global-set-key (kbd "C-M-SPC") 'er/expand-region)
(global-set-key (kbd "C-S-b") 'windmove-left)
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 2021.0823.214515
-;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview dashboard)
+;; Version: 2021.0916.084918
+;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview dashboard mixed-pitch)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by